% This Matlab script runs a simulation of an Integrate and Fire neuron that is performing:
% a set of STDP learning rules on one Exc synapse
% (ran for 19.0 hours to completion of 120 x 300 min simulations)
clear all; path (path, 'CommonLib');
SetLearningK;
%%  Learning configuration tunables:
ProcessingMinutes = 300;
% ProcessingMinutes = 30;
WorkingPoint = '1syn'; SetWorkingPoint; LogPath = ['SimLog\Exc3Dx' num2str(ProcessingMinutes)];

ExcLearningCount = 1;
LearningThetas = [1 1]; LearningTypes = 'CO';
LearningMus = [0 0.01 0.02]; LearningAlphas = 1.01:0.02:1.19;
SynW0s = [0 1];

LearningLambdaPerMinute = 1e-3*ones(ProcessingMinutes,1);

LInFinit; LogHeader; tic;
%% Execution loop
for rule = 1:length (LearningThetas)
	ExcLearningTheta = LearningThetas(rule);
	LearningType = LearningTypes(rule);
	for InhLearningMu = LearningMus
		for ExcLearningAlpha = LearningAlphas
			for ExcSynW0 = SynW0s
				% reset weights
				ExcSynWeights(1:ExcLearningCount) = ExcSynW0;

				LInFneuron;
				SaveNlog;
				sprintf ('loop of %c / %f / %f / %f ended at %f', LearningType, ExcLearningTheta, ExcLearningMu, ExcLearningAlpha, toc)
			end;
		end;
	end;
end;
sprintf ('Elapsed time: %.1f hours', toc / 3600)
