% This Matlab script runs a simulation of an Integrate and Fire neuron that is performing:
% a set of STDP learning rules on one Inh synapse
% (ran for 82.9 hours to completion of 6x6x13 x 300 min simulations)
% (ran for 3.6 hours to completion of 3x6x13 x 30 min simulations)
clear all; path (path, 'CommonLib');
SetLearningK;
%%  Learning configuration tunables:
ProcessingMinutes = 300;
% ProcessingMinutes = 30;
WorkingPoint = '1syn'; SetWorkingPoint; LogPath = ['SimLog\Inh3D' num2str(ProcessingMinutes)];

InhLearningCount = 1;
LearningThetas = [1 1 0.75 0 -0.75 -1]; LearningTypes = 'COOOOO';
LearningMus = [0 0.01 0.02 0.05 0.1 0.2]; LearningAlphas = 0.70:0.05:1.30;

LInFinit; LogHeader; tic;
%% Execution loop
for rule = 1:length (LearningThetas)
	InhLearningTheta = LearningThetas(rule);
	LearningType = LearningTypes(rule);
	for InhLearningMu = LearningMus
		for InhLearningAlpha = LearningAlphas
			% reset weights
			InhSynWeights(1:InhLearningCount) = InhSynW0;

			LInFneuron;
			SaveNlog;
			sprintf ('loop of %c / %f / %f / %f ended at %f', LearningType, InhLearningTheta, InhLearningMu, InhLearningAlpha, toc)
		end;
	end;
end;
sprintf ('Elapsed time: %.1f hours', toc / 3600)
