% This Matlab script runs a simulation of an Integrate and Fire neuron that is performing:
% a set of STDP learning rules on one Inh synapse
% (ran for 9.7 hours to completion of 60 x 300 min simulations)
clear all; path (path, 'CommonLib');
SetLearningK;
%%  Learning configuration tunables:
ProcessingMinutes = 300;
% ProcessingMinutes = 30;
WorkingPoint = '1syn'; SetWorkingPoint; LogPath = ['SimLog\Inh3Dx' num2str(ProcessingMinutes)];

InhLearningCount = 1;
InhLearningTheta = -1;
LearningMus = [0 0.01 0.02]; LearningAlphas = 1.01:0.02:1.19;
SynW0s = [0 1];

LearningLambdaPerMinute = 1e-3*ones(ProcessingMinutes,1);

LInFinit; LogHeader; tic;
%% Execution loop
for InhLearningMu = LearningMus
	for InhLearningAlpha = LearningAlphas
		for InhSynW0 = SynW0s
			% reset weights
			InhSynWeights(1:InhLearningCount) = InhSynW0;

			LInFneuron;
			SaveNlog;
			sprintf ('loop of %c / %f / %f / %f ended at %f', LearningType, InhLearningTheta, InhLearningMu, InhLearningAlpha, toc)
		end;
	end;
end;
sprintf ('Elapsed time: %.1f hours', toc / 3600)
