function SpikeTrains = GenRandonSpikeTrains (timeBins, SinapseCount, dt, rate, GroupsDesc)
% this method generates random spike trains using "Bernoulli process" for each time bin dt
% the temporal spike rate (probability for a spike at (t, t+dt)) is set by:
%	either the "rate" constant
%	or by the complex struct vector "GroupsDesc",
%	which contains a descriptor for the rate temporal function of the different inputs
Rdt = rate*dt;

if (isstruct (GroupsDesc) == 0)
 	SpikeTrains = 1*(rand (timeBins, SinapseCount) <= Rdt); % 1* to convert from logical to float
else
	SpikeTrains = zeros (timeBins, SinapseCount);
	for subG = 1:length (GroupsDesc)
		groupSize = GroupsDesc(subG).GroupCount;

		SubGroupCorrRoot = GroupsDesc(subG).GroupCorr ^ .5;
		X0 = rand (timeBins, 1) <= Rdt; X1 = (1-X0);
		Nu = rand (timeBins, groupSize) <= (Rdt + SubGroupCorrRoot * (1-Rdt));
		Phi = rand (timeBins, groupSize) <= (Rdt * (1-SubGroupCorrRoot));
		for i = 1:groupSize
			SpikeTrains(:,(subG-1)*groupSize+i) = Nu(:,i) .* X0 + Phi(:,i) .* X1;
		end;
	end;
end;
