function SpikeTrains = GenRandonSpikeTrains (timeBins, SinapseCount, dt, rate, GroupsDesc)
% this method generates random spike trains using "Bernoulli process" for each time bin dt
% the temporal spike rate (probability for a spike at (t, t+dt)) is set by:
%	either the "rate" constant
%	or by the complex struct vector "GroupsDesc",
%	which contains a descriptor for the rate temporal function of the different inputs
%%
if (isstruct (GroupsDesc) == 0)
 	SpikeTrains = 1*(rand (timeBins, SinapseCount) <= rate*dt); % 1* to convert from logical to float
else
	SpikeTrains = zeros (timeBins, SinapseCount);
	t = dt*(1:timeBins)';
	id = 1;
	for subG = 1:length (GroupsDesc)
		groupSize = GroupsDesc(subG).GroupCount;

		if (GroupsDesc(subG).AC_P == -1)
			PhiI = 2*pi/groupSize*(1:groupSize);
		else
			PhiI = GroupsDesc(subG).AC_P*ones(groupSize,1);
		end;
		for i = 1:groupSize
			SpikeTrains(:, id) = 1*(rand (timeBins, 1) <= ...
				dt*(GroupsDesc(subG).RateDC+GroupsDesc(subG).RateAC*cos (2*pi*GroupsDesc(subG).AC_F*t+PhiI(i)))); % 1* to convert from logical to float
			id = id + 1;
		end;
	end;
end;
