clear all; path (path, 'CommonLib');
SetLearningK;
%%
IsInh = 1;
if IsInh
	PathPref = 'SimLog\InhBifAlpha300\';
	FileSuffix = 'inh.mat';
	SubFigLetter = 'C';
	[Xp Xd] = CalcMeanOfGammaK ('SimLog\InhSTA60000\', 'O', -1);
else
	PathPref = 'SimLog\ExcBifAlpha300\';
	FileSuffix = 'exc.mat';
	SubFigLetter = 'D';
	[Xp Xd] = CalcMeanOfGammaK ('SimLog\ExcSTA60000\', 'O', 1);
end;

AlphaHat = (1+0.5*Xp)/(1+0.5*Xd); % equation 18

FilesDesc = ReadExcel([PathPref 'batchOut.csv']);
History4Stat = 0.5;
%%
histStep = 0.025;
histEdges = 0:histStep:1;
Wstats = zeros (length(histEdges), length(FilesDesc));
for i = 1:length(FilesDesc)
	load ([PathPref, FilesDesc(i).fileName, FileSuffix]);
	HistorySamples = round (History4Stat*FilesDesc(i).ProcessingMinutes*60);
	
	if IsInh; fluctuatingW = InhSynW(end-HistorySamples+1:end); else fluctuatingW = ExcSynW(end-HistorySamples+1:end); end;
	Wstats (:, i) = histc (fluctuatingW, histEdges);
end;
if IsInh; SimAlphaList = [FilesDesc.InhLearningAlpha;]; else SimAlphaList = [FilesDesc.ExcLearningAlpha;]; end;
SimAlphaListUnique = sort (unique(SimAlphaList));
%%

bifImage = zeros (length(histEdges), length (SimAlphaListUnique));
for i = 1:length (SimAlphaListUnique)
	SimAtAlpha = (SimAlphaList == SimAlphaListUnique(i));
	bifImage(:, i) = sum (Wstats(:, SimAtAlpha), 2);
	bifImage(:, i) = bifImage(:, i) / sum (bifImage(:, i));
end;
% bifImage = bifImage/histStep;
%%
thisFig = figure ('Units', 'centimeters', 'Position', [1 1 12 8]); hold on;
pcolor(SimAlphaListUnique, histEdges, bifImage); shading flat;
set (gca, 'FontName', 'Helvetica', 'FontSize', 8);
xlabel ('\alpha', 'FontName', 'Helvetica', 'FontSize', 9);
ylabel ('w', 'FontName', 'Helvetica', 'FontSize', 9);
cb = colorbar ('FontName', 'Helvetica', 'FontSize', 8);
title (cb, 'P(w)', 'FontName', 'Helvetica', 'FontSize', 8);

Xmin = min(SimAlphaListUnique);
Xmax = max(SimAlphaListUnique);
xlim ([Xmin Xmax]);
X4text = Xmin - 0.15 * (Xmax-Xmin);
text (X4text, 1, SubFigLetter, 'FontName', 'Helvetica', 'FontSize', 9, 'FontAngle', 'italic', 'FontWeight', 'bold');

set(gca,'XTick', Xmin:0.01:Xmax);
if IsInh
	set(gca,'XTick', [1.05, 1.06, 1.08, 1.09]);
else
	set(gca,'XTick', [1.12, 1.13, 1.14, 1.15]);
end;
text (AlphaHat, -0.06, '$\hat{\alpha}$', 'interpreter', 'latex', 'HorizontalAlignment', 'center', 'FontName', 'Helvetica', 'FontSize', 7);
plot ([AlphaHat AlphaHat], [0, 1], '--w');
%%
if IsInh; SaveFigure (thisFig, 'Bif1inhByAlpha', 'tiff'); else SaveFigure (thisFig, 'Bif1excByAlpha', 'tiff'); end;

