clear all; path (path, 'CommonLib');
SetLearningK;
%%
IsInh = 1;
if IsInh
	PathPref = 'SimLog\InhBifMu300\';
	FileSuffix = 'inh.mat';
	SubFigLetter = 'A';
	[Xp Xd] = CalcMeanOfGammaK ('SimLog\InhSTA60000\', 'O', -1);
else
	PathPref = 'SimLog\ExcBifMu300\';
	FileSuffix = 'exc.mat';
	SubFigLetter = 'B';
	[Xp Xd] = CalcMeanOfGammaK ('SimLog\ExcSTA60000\', 'O', 1);
end;

MuCr = 0.25*(Xp/(1+0.5*Xp)-Xd/(1-0.5*Xp)); % equation 20

FilesDesc = ReadExcel([PathPref 'batchOut.csv']);
History4Stat = 0.5;
%%
histStep = 0.025;
histEdges = 0:histStep:1;
Wstats = zeros (length(histEdges), length(FilesDesc));
for i = 1:length(FilesDesc)
	load ([PathPref, FilesDesc(i).fileName, FileSuffix]);
	HistorySamples = round (History4Stat*FilesDesc(i).ProcessingMinutes*60);
	
	if IsInh; fluctuatingW = InhSynW(end-HistorySamples+1:end); else fluctuatingW = ExcSynW(end-HistorySamples+1:end); end;
	Wstats (:, i) = histc (fluctuatingW, histEdges);
end;
if IsInh; SimMuList = [FilesDesc.InhLearningMu;]; else SimMuList = [FilesDesc.ExcLearningMu;]; end;
SimMuListUnique = sort (unique(SimMuList));
%%

bifImage = zeros (length(histEdges), length (SimMuListUnique));
for i = 1:length (SimMuListUnique)
	SimAtMu = (SimMuList == SimMuListUnique(i));
	bifImage(:, i) = sum (Wstats(:, SimAtMu), 2);
	bifImage(:, i) = bifImage(:, i) / sum (bifImage(:, i));
end;
% bifImage = bifImage/histStep;
%%
thisFig = figure ('Units', 'centimeters', 'Position', [1 1 12 8]); hold on;
pcolor(SimMuListUnique, histEdges, bifImage); shading flat;
set (gca, 'FontName', 'Helvetica', 'FontSize', 8);
xlabel('\mu', 'FontName', 'Helvetica', 'FontSize', 9);
ylabel('w', 'FontName', 'Helvetica', 'FontSize', 9);
cb = colorbar ('FontName', 'Helvetica', 'FontSize', 8);
title (cb, 'P(w)', 'FontName', 'Helvetica', 'FontSize', 8);

Xmin = min(SimMuListUnique);
Xmax = max(SimMuListUnique);
xlim ([Xmin Xmax]);
X4text = Xmin - 0.15 * (Xmax-Xmin);
text (X4text, 1, SubFigLetter, 'FontName', 'Helvetica', 'FontSize', 9, 'FontAngle', 'italic', 'FontWeight', 'bold');

if IsInh
	set(gca,'XTick', [0, 0.02, 0.05, 0.07]);
else
	set(gca,'XTick', [0, 0.02, 0.08, 0.10]);
end;
text (MuCr, -0.05, '\mu_c', 'HorizontalAlignment', 'center', 'FontName', 'Helvetica', 'FontSize', 8);
plot ([MuCr MuCr], [0, 1], '--w');
%%
if IsInh; SaveFigure (thisFig, 'Bif1inhByMu', 'tiff'); else SaveFigure (thisFig, 'Bif1excByMu', 'tiff'); end;

