clear all; path (path, 'CommonLib');
PathPref = 'SimLog\Balance60ByInhW0\'; recordID = 4;
FilesDesc = ReadExcel([PathPref 'batchOut.csv']);
Record = FilesDesc(recordID);
%%
if (Record.ExcLearningCount > 0)
	load ([PathPref, Record.fileName, 'exc.mat']);
end;
if (Record.InhLearningCount > 0)
	load ([PathPref, Record.fileName, 'inh.mat']);
end;
%%
StatResolution = 16;
History4Stat = 0.65;
HistorySamples = round (History4Stat*Record.ProcessingMinutes*60);
MinScale = 1/60*(1:Record.ProcessingMinutes*60);

thisFig = figure ('Units', 'centimeters', 'Position', [0 0 20 12]); hold on;

subplot('Position',[0.05 0.7 0.6 0.25]); hold on;
if (Record.InhLearningCount ~= 0);
% 	plot (MinScale, InhSynW');
    Ni2 = floor (Record.InhLearningCount/2);
    for j = 1:Ni2
        plot (MinScale, InhSynW(j,:), 'Color', [0,0,1-0.5*j/Ni2]);
        plot (MinScale, InhSynW(Ni2+j,:), 'Color', [0.5+0.5*j/Ni2,0,0]);
    end;
    plot (MinScale, mean (InhSynW(1:Ni2,:), 1), 'k', 'LineWidth', 2);
    plot (MinScale, mean (InhSynW(Ni2+1:end,:), 1), 'k', 'LineWidth', 2);
else
	plot (MinScale, Record.InhSynW0);
end;
legend (sprintf ('Inh Syn - total %d, learning %d, Mu = %.2f, Alpha = %.2f',...
	Record.InhSynCount, Record.InhLearningCount, Record.InhLearningMu, Record.InhLearningAlpha), 'Location', 'SouthWest');
% title (sprintf ('W learning curve with: CC Exc = %s - CC Inh = %s', Record.ExcCorrTxt, Record.InhCorrTxt));

subplot('Position',[0.05 0.4 0.6 0.25]); hold on;
if (Record.ExcLearningCount ~= 0);
% 	plot (MinScale, ExcSynW');
    Ni2 = Record.ExcLearningCount/2;
    for j = 1:Ni2
        plot (MinScale, ExcSynW(j,:), 'Color', [0,0,1-0.5*j/Ni2]);
        plot (MinScale, ExcSynW(Ni2+j,:), 'Color', [0.5+0.5*j/Ni2,0,0]);
    end;
    plot (MinScale, mean (ExcSynW(1:Ni2,:), 1), 'k', 'LineWidth', 2);
    plot (MinScale, mean (ExcSynW(Ni2+1:end,:), 1), 'k', 'LineWidth', 2);
else
	plot (MinScale, Record.ExcSynW0);
end
legend (sprintf ('Exc Syn - total %d, learning %d, Mu = %.3f, Alpha = %.2f',...
	Record.ExcSynCount, Record.ExcLearningCount, Record.ExcLearningMu, Record.ExcLearningAlpha), 'Location', 'SouthWest');
% subplot('Position',[0.05 0.1 0.6 0.25]);
% plot (1/60*PostSynapticRate);
% legend (sprintf ('<Post synaptic rate> = %.2f (Inh rate = %.2f, Exc rate = %.2f)',...
% 	1/60*mean(PostSynapticRate(end-HistorySamples/60+1:end)), Record.InhMeanRate, Record.ExcMeanRate), 'Location', 'SouthEast')
xlabel ('[min]');

subplot('Position',[0.7 0.7 0.25 0.25]);
if (Record.InhLearningCount > 0)
	iW = reshape (InhSynW(:,end-HistorySamples+1:end), 1, HistorySamples*Record.InhLearningCount);
	hist(iW, StatResolution); xlim ([min(iW) max(iW)]);
end;

subplot('Position',[0.7 0.4 0.25 0.25]);
if (Record.ExcLearningCount ~= 0);
	xW = reshape (ExcSynW(:,end-HistorySamples+1:end), 1, HistorySamples*Record.ExcLearningCount);
	hist(xW, StatResolution); xlim ([min(xW) max(xW)]);
end;

%%
% colorSet = [1,0,0;  1,0.5,0;  0,0.6,0;  0,0.4,0.4;  0,0,1;  0.3,0,0.7;  0.5,0,0.5];
% if (Record.InhLearningCount > 0)
% 	figure; hold on;
% 	histX = 0:0.01:3;
% 	timeC = Record.ProcessingMinutes/6;
% 	for i = 1:3
% 		iW = reshape (InhSynW(:,end-i*timeC+1:end-(i-1)*timeC), 1, timeC*Record.InhLearningCount);
% 		p = histc(iW, histX);
% 		stairs (histX, p, 'Color', colorSet(i,:));
% 	end;
% end;
% %%
% if (Record.ExcLearningCount > 0)
% 	figure; hold on;
% 	histX = 0:0.01:3;
% 	timeC = Record.ProcessingMinutes/6;
% 	for i = 1:3
% 		iW = reshape (ExcSynW(:,end-i*timeC+1:end-(i-1)*timeC), 1, timeC*Record.ExcLearningCount);
% 		p = histc(iW, histX);
% 		stairs (histX, p, 'Color', colorSet(i,:));
% 	end;
% end;