% this Matlab script, plots a single synapse STA ...
clear all; path (path, 'CommonLib');
%%
IsInh = 0;
if IsInh
	PathPref = 'SimLog\InhSTA60000\';
else
	PathPref = 'SimLog\ExcSTA60000\';
end;
FilesDesc = ReadExcel([PathPref 'batchOut.csv']);

colorSet = [1,0,0;  1,0.5,0;  0,0.6,0;  0,0,1;  0.5,0,0.5;  0.3,0,0.7];
W4estimation = [.1 .3 .5 .7 .9];
DoHalfBitShift = 1;
len4fit = 40;
%% collect data set from simulation
T4plot = [];
W4plot = [];
G4plot = [];
T4fit = [];
G4fit = [];

for i = 1:length(FilesDesc)
	if (isempty (find(W4estimation == FilesDesc(i).SynW4sta, 1, 'first')))
		continue;
	end;
	W4plot = [W4plot; FilesDesc(i).SynW4sta];
	expTime = (0:1:len4fit-1)'*FilesDesc(i).dt;
	
	load ([PathPref, FilesDesc(i).fileName, 'sta.mat']);
	if IsInh
		expSTAnormed = InhSTAn(end:-1:end-len4fit+1)/FilesDesc(i).InhMeanRate-1;
	else
		expSTAnormed = ExcSTAn(end:-1:end-len4fit+1)/FilesDesc(i).ExcMeanRate-1;
	end;
	if DoHalfBitShift
		expSTAshifted = [0; expSTAnormed(1:end-1)];
		expSTAnormed = (expSTAnormed+expSTAshifted)/2;
	end
	T4plot = [T4plot, expTime];
	if IsInh
		G4plot = [G4plot, (expSTAnormed+1)*FilesDesc(i).InhMeanRate];
	else
		G4plot = [G4plot, (expSTAnormed+1)*FilesDesc(i).ExcMeanRate];
	end;
	for j = 1:(10*W4plot(i)) % set equivalent weight to each simulation point
		T4fit = [T4fit; expTime];
		G4fit = [G4fit; expSTAnormed./W4plot(i)];
	end;
end;
plotCount = length(W4plot);
%% estimate Gamma
GammaFit = Fit2Gamma (T4fit, G4fit);
%% plot experimental data vs. Gamma
figure; hold on;  plot (T4fit, G4fit, '.'); plot (GammaFit); grid;
%% plot the different STA experimental result
thisFig = figure ('Units', 'centimeters', 'Position', [1 1 8.3 4]); hold on;
set (gca, 'FontName', 'Helvetica', 'FontSize', 9);

plotLegend = cell(plotCount,1);
for i = 1:plotCount
	plot (-T4plot(:, i)*1000, G4plot(:, i),...
		'Color', colorSet(i,:), 'Marker', '.', 'LineStyle', 'none', 'MarkerSize', 10);
	if IsInh
		plotLegend(i) = {sprintf('w^{I} = %.1f', W4plot(i))};
	else
		plotLegend(i) = {sprintf('w^{E} = %.1f', W4plot(i))};
	end;
end;

% plot the expected Gamma dependent graphs on the same plot
for i = 1:plotCount
	time = T4plot(:, i);
	plot( -time*1000,...
		FilesDesc(i).InhMeanRate*(1+W4plot(i)*GammaFit.aG*sin((GammaFit.omegaG*time).^GammaFit.powerG).*exp(-time/GammaFit.tauG)),...
		'Color', colorSet(i,:), 'LineStyle', '--', 'LineWidth', 1);
end;

if IsInh
	legend (plotLegend, 'FontName', 'Helvetica', 'FontSize', 7, 'Location', [0.15 0.45 0.2 0.2]);
	text (1, 10.0, 'B', 'FontName', 'Helvetica', 'FontSize', 9, 'FontAngle', 'italic', 'FontWeight', 'bold');
	ylim ([6.5 10.5]);
	xlabel ('time [mSec]', 'FontName', 'Helvetica', 'FontSize', 9);
else
	legend (plotLegend, 'FontName', 'Helvetica', 'FontSize', 7, 'Location', [0.15 0.55 0.2 0.2]);
	text (1, 17.0, 'A', 'FontName', 'Helvetica', 'FontSize', 9, 'FontAngle', 'italic', 'FontWeight', 'bold');
	ylim ([9.5 17.5]);
	set (gca, 'XTickLabel', '');
end;
legend ('boxoff');
ylabel ('STA [spikes/sec]', 'FontName', 'Helvetica', 'FontSize', 9);
%%
save ([PathPref 'GammaFit.mat'], 'GammaFit');
%%
if IsInh; SaveFigure (thisFig, 'STAinh', 'tiff'); else SaveFigure (thisFig, 'STAexc', 'tiff'); end
