clear all; path (path, 'CommonLib');
SetLearningK;
%% 1syn: Jan 2014
PathPref = 'SimLog\Exc3D300\';
FilesDesc = ReadExcel([PathPref 'batchOut.csv']);

% SubFigLetter = 'A2'; LearningType = 'C'; LearningTheta = 1; % Exc3D300+Exc3Dx300: A = 0.9539, R2 = 0.9443 - used 0:1e-6:1 for better analytical match
% SubFigLetter = 'B2'; LearningType = 'O'; LearningTheta = 1; % Exc3D300+Exc3Dx300: A = 0.9620, R2 = 0.9517 - used 0:1e-6:1 for better analytical match
% SubFigLetter = 'C2'; LearningType = 'O'; LearningTheta = 0.75; % Inh3D300: A = 1.0030, R2 = 0.9995
% SubFigLetter = 'D2'; LearningType = 'O'; LearningTheta = 0; % Inh3D300: A = 0.9999, R2 = 1.0000
% SubFigLetter = 'E2'; LearningType = 'O'; LearningTheta = -0.75; % Inh3D300: A = 1.0025, R2 = 0.9994
SubFigLetter = 'F2'; LearningType = 'O'; LearningTheta = -1; % Exc3D300: A = 1.0050, R2 = 0.9990

[Xp Xd] = CalcMeanOfGammaK ('SimLog\ExcSTA60000\', LearningType, LearningTheta);

AnalyticLearningMus = [1e-6 0.01 0.02 0.05 0.1 0.2];
SimLearningMus = [0 0.01 0.02 0.05 0.1 0.2];
Wstars = 0:1e-4:1; % use 0:1e-6:1 for better analytical match - still not 100% good
History4Stat = 0.5;
%%
AnalyticAlphas = zeros (length(Wstars), length(AnalyticLearningMus));
AnalyticWs = zeros (length(FilesDesc), length(SimLearningMus));

muValues = zeros (length(FilesDesc), length(SimLearningMus));
alphaValues = zeros (length(FilesDesc), length(SimLearningMus));
SimWs = zeros (length(FilesDesc), length(SimLearningMus));
SimWsSTD = zeros (length(FilesDesc), length(SimLearningMus));
DotsPerPlot = zeros (length(SimLearningMus), 1);

plotLegend = cell(length(SimLearningMus),1);
%%
tic;
extraDots = [];
for plotCount = 1:length(SimLearningMus)
	AnalyticAlphas(:, plotCount) = ((1-Wstars)./Wstars).^AnalyticLearningMus(plotCount).*(1+Wstars*Xp)./(1+Wstars*Xd);

	DotsPerPlot (plotCount) = 0;
	for i = 1:length(FilesDesc)
		if (FilesDesc(i).LearningType ~= LearningType || FilesDesc(i).ExcLearningTheta ~= LearningTheta || FilesDesc(i).ExcLearningMu ~= SimLearningMus(plotCount))
			continue;
		end;
		DotsPerPlot(plotCount) = DotsPerPlot (plotCount) + 1;
		d = DotsPerPlot (plotCount);
		load ([PathPref, FilesDesc(i).fileName, 'exc.mat']);
		HistorySamples = round (History4Stat*FilesDesc(i).ProcessingMinutes*60);

		muValues(d, plotCount) = FilesDesc(i).ExcLearningMu;
		alphaValues(d, plotCount) = FilesDesc(i).ExcLearningAlpha;
		SimWs(d, plotCount) = mean (ExcSynW(end-HistorySamples+1:end));
		SimWsSTD(d, plotCount) = std (ExcSynW(end-HistorySamples+1:end));
		AnalyticWs(d, plotCount) = CalcWstar (Wstars, AnalyticAlphas(:, plotCount), FilesDesc(i).ExcLearningAlpha, (SimWs(d, plotCount) < 0.5), SimLearningMus(plotCount));
	end;
end;
toc;
%%
thisFig = figure ('Units', 'centimeters', 'Position', [1 1 7 4.5]); hold on;

set (gca, 'FontName', 'Helvetica', 'FontSize', 9);
colorSet = [1,0,0;  1,0.5,0;  0,0.6,0;  0,0.4,0.4;  0,0,1;  0.3,0,0.7;  0.5,0,0.5];

for plotCount = length(SimLearningMus):-1:1
	plot (AnalyticAlphas(:, plotCount), Wstars, '--', 'Color', colorSet(plotCount,:), 'LineWidth', 1);
% 	plot (alphaValues(1:DotsPerPlot(plotCount), plotCount), AnalyticWs(1:DotsPerPlot(plotCount), plotCount),...
% 		'*', 'Color', colorSet(plotCount,:), 'LineWidth', 2, 'MarkerSize', 8);
end;
for plotCount = length(AnalyticLearningMus):-1:1
	errorbar (alphaValues(1:DotsPerPlot(plotCount), plotCount), SimWs(1:DotsPerPlot(plotCount), plotCount),...
		SimWsSTD(1:DotsPerPlot(plotCount), plotCount), '.', 'Color', colorSet(plotCount,:), 'LineWidth', 1, 'MarkerSize', 6);
	plotLegend(plotCount) = {sprintf('\\mu = %.3f', SimLearningMus(plotCount))};
end;

xlim ([0.7 1.3]);
ylim ([0 1]);
text (1.31, 1, SubFigLetter, 'FontName', 'Helvetica', 'FontSize', 9, 'FontAngle', 'italic', 'FontWeight', 'bold');
% ylabel ('w_{0}', 'FontName', 'Helvetica', 'FontSize', 9);
set (gca, 'YTickLabel', '');
if (LearningTheta ~= -1)
	set (gca, 'XTickLabel', '');
else
	set (gca, 'XTickLabel', (0.7:0.1:1.3), 'FontName', 'Helvetica', 'FontSize', 8);
	xlabel ('\alpha', 'FontName', 'Helvetica', 'FontSize', 9);
end;
%%
CalcR2 (AnalyticWs(1:DotsPerPlot(plotCount), :), SimWs(1:DotsPerPlot(plotCount), :));
%%
if LearningType == 'O'
	SaveFigure (thisFig, sprintf ('W0excO%.2f', LearningTheta), 'tiff');
else
	SaveFigure (thisFig, ['W0exc', LearningType], 'tiff');
end;
