clear all; path (path, 'CommonLib');
SetLearningK;
%% 1syn: Jan 2014
PathPref = 'SimLog\Inh3D300\';
FilesDesc = ReadExcel([PathPref 'batchOut.csv']);

% SubFigLetter = 'A1'; LearningType = 'C'; LearningTheta = 1; % Inh3D300: A = 1.0013, R2 = 0.9992
% SubFigLetter = 'B1'; LearningType = 'O'; LearningTheta = 1; % Inh3D300: A = 1.0009, R2 = 0.9994
% SubFigLetter = 'C1'; LearningType = 'O'; LearningTheta = 0.75; % Inh3D300: A = 0.9988, R2 = 0.9926
% SubFigLetter = 'D1'; LearningType = 'O'; LearningTheta = 0; % Inh3D300: A = 0.9998, R2 = 0.9998
% SubFigLetter = 'E1'; LearningType = 'O'; LearningTheta = -0.75; % Inh3D300: A = 1.0024, R2 = 0.9993
SubFigLetter = 'F1'; LearningType = 'O'; LearningTheta = -1; % Inh3D300+Inh3Dx300: A = 0.9892, R2 = 0.9708 - used 0:1e-6:1 does not make a better analytical match

[Xp Xd] = CalcMeanOfGammaK ('SimLog\InhSTA60000\', LearningType, LearningTheta);

AnalyticLearningMus = [1e-6 0.01 0.02 0.05 0.1 0.2];
SimLearningMus = [0 0.01 0.02 0.05 0.1 0.2];
Wstars = 0:1e-4:1; % use 0:1e-6:1 for better analytical match - still not 100% good
History4Stat = 0.5;
%%
AnalyticAlphas = zeros (length(Wstars), length(AnalyticLearningMus));
AnalyticWs = zeros (length(FilesDesc), length(SimLearningMus));

muValues = zeros (length(FilesDesc), length(SimLearningMus));
alphaValues = zeros (length(FilesDesc), length(SimLearningMus));
SimWs = zeros (length(FilesDesc), length(SimLearningMus));
SimWsSTD = zeros (length(FilesDesc), length(SimLearningMus));
DotsPerPlot = zeros (length(SimLearningMus), 1);

plotLegend = cell(length(SimLearningMus),1);
%%
tic;
extraDots = [];
for plotCount = 1:length(SimLearningMus)
	AnalyticAlphas(:, plotCount) = ((1-Wstars)./Wstars).^AnalyticLearningMus(plotCount).*(1+Wstars*Xp)./(1+Wstars*Xd);

	DotsPerPlot (plotCount) = 0;
	for i = 1:length(FilesDesc)
		if (FilesDesc(i).LearningType ~= LearningType || FilesDesc(i).InhLearningTheta ~= LearningTheta || FilesDesc(i).InhLearningMu ~= SimLearningMus(plotCount))
			continue;
		end;
		DotsPerPlot(plotCount) = DotsPerPlot (plotCount) + 1;
		d = DotsPerPlot (plotCount);
		load ([PathPref, FilesDesc(i).fileName, 'inh.mat']);
		HistorySamples = round (History4Stat*FilesDesc(i).ProcessingMinutes*60);

		muValues(d, plotCount) = FilesDesc(i).InhLearningMu;
		alphaValues(d, plotCount) = FilesDesc(i).InhLearningAlpha;
		SimWs(d, plotCount) = mean (InhSynW(end-HistorySamples+1:end));
		SimWsSTD(d, plotCount) = std (InhSynW(end-HistorySamples+1:end));
		AnalyticWs(d, plotCount) = CalcWstar (Wstars, AnalyticAlphas(:, plotCount), FilesDesc(i).InhLearningAlpha, (SimWs(d, plotCount) < 0.5), SimLearningMus(plotCount));
	end;
end;
toc;
%%
thisFig = figure ('Units', 'centimeters', 'Position', [1 1 7 4.5]); hold on;

set (gca, 'FontName', 'Helvetica', 'FontSize', 9);
colorSet = [1,0,0;  1,0.5,0;  0,0.6,0;  0,0.4,0.4;  0,0,1;  0.3,0,0.7;  0.5,0,0.5];

for plotCount = length(SimLearningMus):-1:1
	errorbar (alphaValues(1:DotsPerPlot(plotCount), plotCount), SimWs(1:DotsPerPlot(plotCount), plotCount),...
		SimWsSTD(1:DotsPerPlot(plotCount), plotCount), '.', 'Color', colorSet(plotCount,:), 'LineWidth', 1, 'MarkerSize', 6);
	plotLegend(plotCount) = {sprintf('\\mu = %.2f', SimLearningMus(plotCount))};
end;
for plotCount = length(AnalyticLearningMus):-1:1
	plot (AnalyticAlphas(:, plotCount), Wstars, '--', 'Color', colorSet(plotCount,:), 'LineWidth', 1);
% 	plot (alphaValues(1:DotsPerPlot(plotCount), plotCount), AnalyticWs(1:DotsPerPlot(plotCount), plotCount),...
% 		'*', 'Color', colorSet(plotCount,:), 'LineWidth', 2, 'MarkerSize', 8);
end;

xlim ([0.7 1.3]);
ylim ([0 1]);
ylabel ('w_{0}', 'FontName', 'Helvetica', 'FontSize', 8);
text (1.31, 1, SubFigLetter, 'FontName', 'Helvetica', 'FontSize', 9, 'FontAngle', 'italic', 'FontWeight', 'bold');
if (LearningTheta ~= -1)
	set (gca, 'XTickLabel', '');
else
	legend (plotLegend, 'FontName', 'Helvetica', 'FontSize', 7, 'Location', 'SouthWest',...
		'PlotBoxAspectRatioMode', 'manual', 'PlotBoxAspectRatio', [1 0.7 1]);
	legend ('boxoff');
	set (gca, 'XTickLabel', (0.7:0.1:1.3), 'FontName', 'Helvetica', 'FontSize', 8);
	xlabel ('\alpha', 'FontName', 'Helvetica', 'FontSize', 9);
end;
%%
CalcR2 (AnalyticWs(1:DotsPerPlot(plotCount), :), SimWs(1:DotsPerPlot(plotCount), :));
%%
if LearningType == 'O'
	SaveFigure (thisFig, sprintf ('W0inhO%.2f', LearningTheta), 'tiff');
else
	SaveFigure (thisFig, ['W0inh', LearningType], 'tiff');
end;
